Developing gocept.selenium
==========================

:Author:
    `gocept <http://gocept.com/>`_ <mail@gocept.com>

:Online documentation:
    https://goceptselenium.readthedocs.org/

:PyPI page:
    https://pypi.python.org/pypi/gocept.selenium/

:Issue tracker:
    https://github.com/gocept/gocept.selenium/issues

:Source code:
    https://github.com/gocept/gocept.selenium

:Current change log:
    https://raw.githubusercontent.com/gocept/gocept.selenium/master/CHANGES.rst

Documentation
-------------

In order to build the Sphinx documentation, run the following command with a
python, where sphinx is installed::

    $ python setup.py build_sphinx

The generated HTML gets stored in ``doc/_build/html``.
